{% load i18n %}
{% load thumbnail %}

<div id="image-thumbnails">
    {% for image in image_list %}
        {% thumbnail image.image "120x120" crop="center" as im %}
            <a class="thumb" rel="gallery-image[ims_gal]" href="{{ image.image.url }}"><img class="preview" src="{{ im.url }}"></a>
        {% endthumbnail %}
    {% endfor %}
    {% include "pagination-template/pagination.html" %}
</div>


